
#define STRICT

#include <windows.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#include "icapi.h"

#ifdef WIN32
	char ICAPIFileName[] = "ICW32API.DLL";
#else
	char ICAPIFileName[] = "ICW16API.DLL";
#endif

/***************************************************************************/
static char szICVersionKey[] 	= "WPConfig\\Apps\\ICWin%s.%d";
static char szICPlatformKey[] 	= "Platform";				
static char szICLanguageKey[] 	= "Language";				
static char szICPathSharedKey[]	= "Paths\\Shared";

static char szDefaultPlatform[5] = "Win32";
static char szDefaultLanguage[3] = "US";

/***************************************************************************/
long WPICAPILocateModule(LPSTR pPlatform, LPSTR pVersion, LPSTR pLanguage
						 ,LPSTR ICAPIModuleName, long cbICAPIModuleName)
	{
	int 	Version;
	LONG 	cbBuf;
	char 	szBuf[256];
	HKEY	hKey;

	if (pPlatform == NULL){ pPlatform = szDefaultPlatform; }
	if (pLanguage == NULL){ pLanguage = szDefaultLanguage; }

    cbBuf = sizeof(szBuf);
	for ( Version =1                             ,ICAPIModuleName[0] = 0
        ;(Version<=WPICAPI_MAX_VERSION_ENTRIES)&&(ICAPIModuleName[0]== 0)
		; Version++)
		{
		/*-------------------------------------------------------------------
		* Try to open the next InfoCentral version key
		*------------------------------------------------------------------*/
		sprintf(szBuf, szICVersionKey, pVersion, Version);
		if (RegOpenKey(HKEY_CLASSES_ROOT, (LPCSTR)szBuf, &hKey)
					== ERROR_SUCCESS)
			{
			/*---------------------------------------------------------------
			* The version key exists (matches), see if the platform matches
			*--------------------------------------------------------------*/
			cbBuf = sizeof(szBuf);
			if (RegQueryValue(hKey, (LPCSTR)szICPlatformKey, szBuf, &cbBuf)
							== ERROR_SUCCESS)
				{
				if (stricmp(pPlatform, szBuf) == 0)
					{
					/*-------------------------------------------------------
					* The platform matches, see if the Language matches
					*------------------------------------------------------*/
					cbBuf = sizeof(szBuf);
					if (RegQueryValue(hKey, (LPCSTR)szICLanguageKey
									 ,szBuf, &cbBuf) == ERROR_SUCCESS)
						{
						if (stricmp(pLanguage, szBuf) == 0)
							{
							/*-----------------------------------------------
							* The language matches, get the path for the API
							* module
							*----------------------------------------------*/
							cbBuf = sizeof(szBuf);
							if (RegQueryValue(hKey, (LPCSTR)szICPathSharedKey
											 ,szBuf, &cbBuf) == ERROR_SUCCESS)
								{
								/*-------------------------------------------
								* Format the fully qualified path for the
								* InfoCentral API module.
								* strncat will will only copy the max number
								* of chars and will place a NULL as the last
								* character of the string even if truncation
								* needed to occur.  On the other hand strncpy
								* will not place the NULL at the end of the
								* string if truncation is neccessary.
								*------------------------------------------*/
								strcpy (ICAPIModuleName, szBuf);
								strncat(ICAPIModuleName, szBuf
									   ,cbICAPIModuleName);
								strncat(ICAPIModuleName, ICAPIFileName
									   ,cbICAPIModuleName);
								} /* if ICPathSharedKey */

							} /* if pLanguage */

						} /* if ICLanguageKey */

					} /* if pPlatform */

				} /* if ICPlatform */

			RegCloseKey(hKey);

			} /* if RegOpenKey */

		} /* for */

	return(ICAPIModuleName[0]==0 ? 1 : NO_ERROR);
	}

/***************************************************************************/

